Module opaque_ke::errors[][src]

A list of error types which are produced during an execution of the protocol

Enums

InternalPakeError

Represents an error in the manipulation of internal cryptographic data

PakeError

Represents an error in password checking

ProtocolError

Represents an error in protocol handling