Enum InternalError

pub enum InternalError<T = Infallible> {
    Custom(T),
    InvalidByteSequence,
    SizeError {
        name: &'static str,
        len: usize,
        actual_len: usize,
    },
    PointError,
    HashToScalar,
    HkdfError,
    HmacError,
    KsfError,
    SealOpenHmacError,
    IncompatibleEnvelopeModeError,
    OprfError(Error),
    OprfInternalError(InternalError),
}
Represents an error in the manipulation of internal cryptographic data

Variants



Custom(T)

Custom SecretKey error type



InvalidByteSequence

Deserializing from a byte sequence failed



SizeError

Invalid length for {name}: expected {len}, but is actually {actual_len}.

Fields

name: &'static str

name

len: usize

length

actual_len: usize

actual



PointError

Could not decompress point.



HashToScalar

Size of input is empty or longer then u16::MAX.



HkdfError

Computing HKDF failed while deriving subkeys



HmacError

Computing HMAC failed while supplying a secret key



KsfError

Computing the key stretching function failed



SealOpenHmacError

This error occurs when the envelope seal open hmac check fails HMAC check in seal open failed.



IncompatibleEnvelopeModeError

This error occurs when attempting to open an envelope of the wrong type (base mode, custom identifier)



OprfError(Error)

Error from the OPRF evaluation



OprfInternalError(InternalError)

Error from the OPRF evaluation

Implementations

Source

impl InternalError

pub fn into_custom<T>(self) -> InternalError<T>

Convert InternalError<Infallible> into InternalError<T>