Enum opaque_ke::errors::InternalPakeError[][src]

pub enum InternalPakeError {
    InvalidByteSequence,
    SizeError {
        name: &'static str,
        len: usize,
        actual_len: usize,
    },
    PointError,
    SubGroupError,
    HashingFailure,
    HashToCurveError,
    HkdfError,
    HmacError,
    SlowHashError,
    SealError,
    SealOpenError,
    SealOpenHmacError,
    InvalidEnvelopeStructureError,
    IncompatibleEnvelopeModeError,
    UnexpectedEnvelopeContentsError,
}

Represents an error in the manipulation of internal cryptographic data

Variants

InvalidByteSequence

Deserializing from a byte sequence failed

SizeError

Invalid length for {name}: expected {len}, but is actually {actual_len}.

Fields of SizeError

name: &'static str

name

len: usize

length

actual_len: usize

actual

PointError

Could not decompress point.

SubGroupError

Key belongs to a small subgroup!

HashingFailure

hashing to a key failed

HashToCurveError

Computing the hash-to-curve function failed

HkdfError

Computing HKDF failed while deriving subkeys

HmacError

Computing HMAC failed while supplying a secret key

SlowHashError

Computing the slow hashing function failed

SealError

This error occurs when the envelope seal fails Constructing the envelope seal failed.

SealOpenError

This error occurs when the envelope seal open fails Opening the envelope seal failed.

SealOpenHmacError

This error occurs when the envelope seal open hmac check fails HMAC check in seal open failed.

InvalidEnvelopeStructureError

This error occurs when the envelope cannot be constructed properly based on the credentials that were specified to be required.

IncompatibleEnvelopeModeError

This error occurs when attempting to open an envelope of the wrong type (base mode, custom identifier)

UnexpectedEnvelopeContentsError

This error occurs when the envelope is opened and deserialization fails