Enum opaque_ke::errors::ProtocolError[][src]

pub enum ProtocolError {
    VerificationError(PakeError),
    ServerError,
    ServerInvalidEnvelopeCredentialsFormatError,
    ClientError,
}

Represents an error in protocol handling

Variants

VerificationError(PakeError)

This error results from an error during password verification

Internal error during password verification: {0}

ServerError

This error occurs when the server answer cannot be handled Server response cannot be handled.

ServerInvalidEnvelopeCredentialsFormatError

This error occurs when the server specifies an envelope credentials format that is invalid

ClientError

This error occurs when the client request cannot be handled Client request cannot be handled.