Enum opaque_ke::errors::InternalPakeError [−][src]
Represents an error in the manipulation of internal cryptographic data
Variants
Deserializing from a byte sequence failed
Invalid length for {name}: expected {len}, but is actually {actual_len}.
Could not decompress point.
Key belongs to a small subgroup!
hashing to a key failed
Computing the hash-to-curve function failed
Computing HKDF failed while deriving subkeys
Computing HMAC failed while supplying a secret key
Computing the slow hashing function failed
This error occurs when the envelope seal fails Constructing the envelope seal failed.
This error occurs when the envelope seal open fails Opening the envelope seal failed.
This error occurs when the envelope seal open hmac check fails HMAC check in seal open failed.
This error occurs when the envelope cannot be constructed properly based on the credentials that were specified to be required.
This error occurs when attempting to open an envelope of the wrong type (base mode, custom identifier)
This error occurs when the envelope is opened and deserialization fails